// ***************************************************************************
// ***************************************************************************
// ***************************************************************************
// ***************************************************************************

#include <stdio.h>
#include "platform.h"
#include "xbasic_types.h"
#include "xstatus.h"
#include "xil_io.h"
#include "xparameters.h"
#include "xuartlite_l.h"

#define CF_BASEADDR   XPAR_AXI_AD9747_0_BASEADDR
#define UART_BASEADDR XPAR_RS232_UART_1_BASEADDR

// ***************************************************************************
// ***************************************************************************

char inbyte(void);
void xil_printf(const char *ctrl1, ...);

void delay_ms(u32 ms_count) {
  u32 count;
  for (count = 0; count < ((ms_count * 100000) + 1); count++) {
    asm("nop");
  }
}

u32 user_exit(void) {
  while (!XUartLite_IsReceiveEmpty(UART_BASEADDR)) {
    if (XUartLite_RecvByte(UART_BASEADDR) == 'q') {
      return(1);
    }
  }
  return(0);
}

// clocks must be in mhz

u32 ad9747_dds_pf(u32 phase, u32 sin_clk, u32 dac_clk) {
  u32 p_offset;
  u32 p_incr;
  p_offset = (phase*0xffff)/360;
  p_incr = ((sin_clk*0xffff)/dac_clk) | 0x1;
  return((p_offset<<16) | p_incr);
}

void ad9747_dds_setup(u32 f1, u32 f2) {
  Xil_Out32((CF_BASEADDR + 0x08), ad9747_dds_pf(0, f1, 250));
  Xil_Out32((CF_BASEADDR + 0x0c), ad9747_dds_pf(0, f2, 250));
  Xil_Out32((CF_BASEADDR + 0x04), 0x0);
  Xil_Out32((CF_BASEADDR + 0x04), 0x1);
  xil_printf("dac dds setup(%dMHz, %dMHz).\n\r", f1, f2);
}

// ***************************************************************************
// ***************************************************************************

int main() {

  init_platform();

  ad9747_dds_setup(45, 29);
  xil_printf("done.\n\r");
  cleanup_platform();
  return(0);
}

// ***************************************************************************
// ***************************************************************************
